"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDefaultSpace = void 0;
const tslib_1 = require("tslib");
const FS = tslib_1.__importStar(require("fs"));
const Path = tslib_1.__importStar(require("path"));
const core_1 = require("@magicspace/core");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const x = tslib_1.__importStar(require("x-value"));
const SPACE_LOGGER = {
    info(event) {
        switch (event.type) {
            case 'loaded-composable-module':
                log('space', 'info', `loaded composable module ${event.path}`);
                break;
            case 'run-lifecycle-script':
                log('space', 'info', `run ${event.lifecycle} script ${JSON.stringify(event.script)}`);
                break;
        }
    },
    stdout(data) {
        process.stdout.write(data);
    },
    stderr(data) {
        process.stderr.write(data);
    },
};
function log(type, _level, message) {
    const prefix = chalk_1.default.blue(`[${type}] `);
    console.info(message.replace(/^/gm, prefix));
}
async function createDefaultSpace(projectDir, magicspaceDir) {
    let config;
    if (typeof magicspaceDir === 'string') {
        try {
            magicspaceDir = Path.resolve(magicspaceDir);
            if (!FS.existsSync(magicspaceDir)) {
                return 'magicspace-dir-not-exists';
            }
            config = await (0, core_1.resolveMagicspaceConfig)(magicspaceDir);
        }
        catch (error) {
            if (error instanceof x.TypeConstraintError) {
                throw `Error validating boilerplate options:\n${error.message}`;
            }
            else {
                throw error;
            }
        }
    }
    return new core_1.Space(core_1.DEFAULT_FILE_OBJECT_CREATOR_MAP, core_1.DEFAULT_EXTENSION_TO_FILE_TYPE_MAP, projectDir, config, SPACE_LOGGER);
}
exports.createDefaultSpace = createDefaultSpace;
//# sourceMappingURL=@space.js.map