"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateOptions = void 0;
const tslib_1 = require("tslib");
const Path = tslib_1.__importStar(require("path"));
const core_1 = require("@magicspace/core");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const clime_1 = require("clime");
const FSExtra = tslib_1.__importStar(require("fs-extra"));
const prompts_1 = tslib_1.__importDefault(require("prompts"));
const _constants_1 = require("../@constants");
class CreateOptions extends clime_1.Options {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "schema", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
}
tslib_1.__decorate([
    (0, clime_1.option)({
        toggle: true,
        description: 'Generate JSON schema for boilerplate.json',
        default: false,
    }),
    tslib_1.__metadata("design:type", Boolean)
], CreateOptions.prototype, "schema", void 0);
exports.CreateOptions = CreateOptions;
let default_1 = class default_1 extends clime_1.Command {
    async execute(boilerplate, { schema: toGenerateJSONSchema }) {
        var _a;
        const magicspaceDir = Path.resolve(core_1.DEFAULT_MAGICSPACE_DIRNAME);
        if (FSExtra.existsSync(magicspaceDir)) {
            throw new clime_1.ExpectedError(`Folder ${JSON.stringify(core_1.DEFAULT_MAGICSPACE_DIRNAME)} already exists`);
        }
        const { examples, Options } = (0, core_1.resolveBoilerplateModule)(boilerplate, process.cwd());
        let example;
        if (examples && examples.length > 1) {
            example = (await (0, prompts_1.default)({
                type: 'select',
                name: 'example',
                message: 'Select a boilerplate example configuration',
                instructions: false,
                choices: examples.map(example => {
                    var _a;
                    return {
                        title: (_a = example.name) !== null && _a !== void 0 ? _a : 'default',
                        description: example.description,
                        value: example,
                    };
                }),
            })).example;
            if (!example) {
                return;
            }
        }
        else {
            example = examples === null || examples === void 0 ? void 0 : examples[0];
        }
        const configFilePath = Path.join(magicspaceDir, 'boilerplate.json');
        const extendsSpecifier = /^[.]{1,2}[\\/]/.test(boilerplate)
            ? Path.relative(magicspaceDir, Path.resolve(boilerplate)).replace(/\\/g, '/')
            : boilerplate;
        await FSExtra.outputFile(configFilePath, `${JSON.stringify({
            ...(toGenerateJSONSchema
                ? { $schema: _constants_1.CONFIG_SCHEMA_FILE_NAME }
                : undefined),
            boilerplate: extendsSpecifier,
            options: (_a = example === null || example === void 0 ? void 0 : example.options) !== null && _a !== void 0 ? _a : {},
        }, undefined, 2)}\n`);
        if (toGenerateJSONSchema && Options) {
            const configSchemaPath = Path.join(magicspaceDir, _constants_1.CONFIG_SCHEMA_FILE_NAME);
            await FSExtra.outputFile(configSchemaPath, JSON.stringify((0, core_1.buildConfigSchema)(Options), undefined, 2));
        }
        return `\
Created magicspace configuration at ${JSON.stringify(Path.relative('.', configFilePath))}.
Please review/edit the configuration file and run ${chalk_1.default.yellow('magicspace init')} to initialize.`;
    }
};
tslib_1.__decorate([
    clime_1.metadata,
    tslib_1.__param(0, (0, clime_1.param)({
        description: 'Boilerplate specifier',
        required: true,
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, CreateOptions]),
    tslib_1.__metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = tslib_1.__decorate([
    (0, clime_1.command)({
        description: 'Create magicspace config file',
    })
], default_1);
exports.default = default_1;
//# sourceMappingURL=create.js.map