"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InitOptions = void 0;
const tslib_1 = require("tslib");
const Path = tslib_1.__importStar(require("path"));
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const clime_1 = require("clime");
const _command_1 = require("../@command");
const _space_1 = require("../@space");
class InitOptions extends _command_1.CommonOptions {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "ours", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
}
tslib_1.__decorate([
    (0, clime_1.option)({
        toggle: true,
        description: 'Use "ours" merge strategy',
        default: false,
    }),
    tslib_1.__metadata("design:type", Boolean)
], InitOptions.prototype, "ours", void 0);
exports.InitOptions = InitOptions;
let default_1 = class default_1 extends clime_1.Command {
    async execute(projectDir, options) {
        const space = await (0, _space_1.createDefaultSpace)(Path.resolve(projectDir), Path.resolve(projectDir, options.magicspace));
        if (space === 'magicspace-dir-not-exists') {
            throw new clime_1.ExpectedError('Magicspace configuration not found');
        }
        const result = await space.initialize(options);
        switch (result) {
            case true:
                return `\
Magicspace initialization started, please review and commit changes to complete the initialize merge.

Please avoid resetting the on-going merge if you want to continue and complete this initialization.
Otherwise, you can use ${chalk_1.default.yellow('git merge --abort')} to cancel this initialization and start over again.`;
            case 'not-repository-root':
                throw new clime_1.ExpectedError(`Project directory ${JSON.stringify(projectDir)} is not repository root`);
            case 'merge-in-progress':
                throw new clime_1.ExpectedError('A merge is already in progress, please resolve it before continue');
            case 'empty-repository':
                throw new clime_1.ExpectedError('You need to make an initial commit before initializing the repository with magicspace');
            case 'already-initialized':
                throw new clime_1.ExpectedError(`This repository has already been initialized with magicspace, run ${chalk_1.default.yellow('magicspace update')} instead`);
        }
    }
};
tslib_1.__decorate([
    clime_1.metadata,
    tslib_1.__param(0, (0, clime_1.param)({
        default: '.',
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, InitOptions]),
    tslib_1.__metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = tslib_1.__decorate([
    (0, clime_1.command)({
        description: 'Initialize magicspace',
    })
], default_1);
exports.default = default_1;
//# sourceMappingURL=init.js.map