"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Path = tslib_1.__importStar(require("path"));
const clime_1 = require("clime");
const prompts_1 = tslib_1.__importDefault(require("prompts"));
const _space_1 = require("../@space");
let default_1 = class default_1 extends clime_1.Command {
    async execute(projectDir) {
        const space = await (0, _space_1.createDefaultSpace)(Path.resolve(projectDir));
        if (!space.isRepositoryRoot()) {
            throw new clime_1.ExpectedError(`Project directory ${JSON.stringify(projectDir)} is not repository root`);
        }
        if (!space.isMerging()) {
            throw new clime_1.ExpectedError('This project is not actively merging');
        }
        const renames = space.listPendingPossibleDirectoryRenames();
        if (!renames.length) {
            return 'No pending possible directory renames detected.';
        }
        const selectedRenames = (await (0, prompts_1.default)([
            {
                type: 'multiselect',
                name: 'renames',
                message: 'Select directory renames to apply',
                instructions: false,
                choices: renames.map(rename => {
                    return {
                        title: `${rename.from} -> ${rename.to}`,
                        value: rename,
                    };
                }),
            },
        ])).renames;
        if (selectedRenames.length) {
            space.renameDirectories(selectedRenames);
            return 'Renaming completed.';
        }
        else {
            return 'Nothing selected.';
        }
    }
};
tslib_1.__decorate([
    clime_1.metadata,
    tslib_1.__param(0, (0, clime_1.param)({
        default: '.',
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String]),
    tslib_1.__metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = tslib_1.__decorate([
    (0, clime_1.command)({
        description: 'Update possible renamed directories interactively',
    })
], default_1);
exports.default = default_1;
//# sourceMappingURL=update-dirs.js.map