"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Path = tslib_1.__importStar(require("path"));
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const clime_1 = require("clime");
const _command_1 = require("../@command");
const _space_1 = require("../@space");
const _utils_1 = require("../@utils");
let default_1 = class default_1 extends clime_1.Command {
    async execute(projectDir, options) {
        const space = await (0, _space_1.createDefaultSpace)(Path.resolve(projectDir), Path.resolve(projectDir, options.magicspace));
        if (space === 'magicspace-dir-not-exists') {
            throw new clime_1.ExpectedError('Magicspace configuration not found');
        }
        const result = await space.update();
        switch (result) {
            case true:
                const renames = space.listPendingPossibleDirectoryRenames();
                return (0, _utils_1.compact)([
                    `\
Update applied, please review and commit changes to complete the update merge.

Please avoid resetting the on-going merge if you want to continue and complete this update.
Otherwise, you can use ${chalk_1.default.yellow('git merge --abort')} to cancel this update and start over again.`,
                    renames.length &&
                        `\
Possible renamed directories detected:

${renames.map(({ from, to }) => `  - ${from} -> ${to}`).join('\n')}

Execute ${chalk_1.default.yellow('magicspace update-dirs')} to update those directories interactively.`,
                ]).join('\n\n');
            case 'not-repository-root':
                throw new clime_1.ExpectedError(`Project directory ${JSON.stringify(projectDir)} is not repository root`);
            case 'merge-in-progress':
                throw new clime_1.ExpectedError('A merge is already in progress, please resolve it before continue');
            case 'empty-repository':
                throw new clime_1.ExpectedError('You need to make an initial commit and initialize the repository with magicspace');
            case 'not-initialized':
                throw new clime_1.ExpectedError(`This repository has not been initialized with magicspace yet, run ${chalk_1.default.yellow('magicspace init')} first`);
            case 'already-up-to-date':
                return 'Already up-to-date.';
        }
    }
};
tslib_1.__decorate([
    clime_1.metadata,
    tslib_1.__param(0, (0, clime_1.param)({
        default: '.',
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, _command_1.CommonOptions]),
    tslib_1.__metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = tslib_1.__decorate([
    (0, clime_1.command)({
        description: 'Update magicspace',
    })
], default_1);
exports.default = default_1;
//# sourceMappingURL=update.js.map